@@ -2,4 +2,4 @@ from .coexist import find_coexistent_mu, MuSearchRecord
 
 from .coexist import *
 
-from .interface import evolve_and_elongate_interface
+from .interface import evolve_and_elongate_interface, elongate_interface
